@@ -31,7 +31,7 @@
 #define HAVE_EXECINFO_H 1
 #define HAVE_FCNTL_H 1
 #define HAVE_FCNTL_DIRECT 1
-#define HAVE_FENV_H 1
+/* #undef HAVE_FENV_H */
 #define HAVE_FLOAT_H 1
 #define HAVE_FNMATCH_H 1
 /* #undef HAVE_FPU_CONTROL_H */
@@ -396,8 +396,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "NetBSD"
-#define MACHINE_TYPE "aarch64"
-#define DEFAULT_MACHINE "aarch64"
+#define MACHINE_TYPE "riscv64"
+#define DEFAULT_MACHINE "riscv64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -533,16 +533,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 22
+#define MYSQL_VERSION_PATCH 23
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.6.22"
+#define PACKAGE_STRING "MySQL Server 10.6.23"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.6.22"
-#define VERSION "10.6.22"
+#define PACKAGE_VERSION "10.6.23"
+#define VERSION "10.6.23"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
