@@ -335,7 +335,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-#define WORDS_BIGENDIAN 1 
+/* #undef WORDS_BIGENDIAN */
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -396,8 +396,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "NetBSD"
-#define MACHINE_TYPE "m68k"
-#define DEFAULT_MACHINE "m68k"
+#define MACHINE_TYPE "earmv6hf"
+#define DEFAULT_MACHINE "earmv6hf"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -533,16 +533,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 22
+#define MYSQL_VERSION_PATCH 23
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.6.22"
+#define PACKAGE_STRING "MySQL Server 10.6.23"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.6.22"
-#define VERSION "10.6.22"
+#define PACKAGE_VERSION "10.6.23"
+#define VERSION "10.6.23"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
